@@ -22,7 +22,7 @@
 
 
 #include <qcanvas.h>
-#include <samplevalueview.h>
+#include "samplevalueview.h"
 #include "pics/icons.h"
 /**
 @author Predrag Viceic
@@ -52,6 +52,8 @@ public:
     void setDrawHandles(int tf);
     bool operator<( const BeatLine bl);
     bool operator==( const BeatLine bl);
+    QRect* getMidiNoteHandle();
+    void setMidiNote(int mn);
 
 
 protected:
@@ -62,8 +64,11 @@ protected:
     QRect* handle;
     QRect* removeHandle;
     QRect* lockunlockHandle;
+    QRect* midiNoteHandle;
+
     SampleValueView* sampleValueView;
     int drawHandles;
+    int midiNote;
 };
 
 #endif
