@@ -46,7 +46,7 @@ DrawSoundWidget::DrawSoundWidget(QWidget *parent, const char *name,SoundManager*
                 0,20,0,canvas->height()-20,canvas,TRUE);
         selection->hide();
 
-        //verticalSelections.setAutoDelete(TRUE);
+        lockedBeatRects.setAutoDelete(TRUE);
 
         playline=new PlayLine(canvas,0);
 	QPen* pen =new QPen();
@@ -85,11 +85,22 @@ DrawSoundWidget::DrawSoundWidget(QWidget *parent, const char *name,SoundManager*
         sampleValueView=new SampleValueView(soundManager,canvas);
         sampleValueView->hide();
         setAcceptDrops(TRUE);
+        scrollTimer = new QTimer( this );
+        scrollTimer->stop();
+        connect(scrollTimer, SIGNAL(timeout()),this, SLOT(scroll()));
 
+        keyboardView=new KeyboardView(canvas);
+        keyboardView->hide();
 }
 
  void DrawSoundWidget::contentsMousePressEvent( QMouseEvent * mouseEvent){
         QPoint pos=mouseEvent->pos();
+        //remove keyboard view if not clicked
+        if(keyboardView->isVisible() && !keyboardView->rect().contains(pos)){
+            keyboardView->hide();
+        }
+        
+        
         int pos_x=pos.x();
         long sample_pos=pos.x()*getZoomRatio();
         if(selection->isVisible())
@@ -133,18 +144,29 @@ DrawSoundWidget::DrawSoundWidget(QWidget *parent, const char *name,SoundManager*
                                     lockedBeatLines.remove(beatline);
                                     if(lockedBeatLines.count()==0)
                                         emit(hasLockedBeatLines(FALSE));
+
                             }else{
                                     beatline->lock();
                                     lockedBeatLines.append(beatline);
                                     if(lockedBeatLines.count()==1)
                                         emit(hasLockedBeatLines(TRUE));
-
                                     if(beatline->isBpmLine())
                                             bpmLines.remove(beatline);
                                     else
                                             beatLines.remove(beatline);
                             }
                             updateBeatLines();
+                            updateLockedBeatRects();
+                            emit(beatLinesChanged(toArray(beatLines)));
+                            emit(lockedBeatLinesChanged(toArray(lockedBeatLines)));
+                }else if(BeatLine* beatline=getAssignableBeatLine(mouseEvent->pos())){
+                    keyboardView->setX(beatline->x());
+                    keyboardView->setY(canvas->height()-30);
+                    keyboardView->show();
+                    canvas->update();
+                }else if(LockedBeatRect* beatrect=getMovableBeatRect(mouseEvent->pos())){
+                    beatrect->setSelected(TRUE);
+                    canvas->update();
                 }else{
                     QCanvasItemList colisions=canvas->collisions(pos);
                     /*
@@ -166,7 +188,8 @@ DrawSoundWidget::DrawSoundWidget(QWidget *parent, const char *name,SoundManager*
                                             beatLines.remove(temp);
                             }
                             updateBeatLines();
-                    }else*/ if(!colisions.isEmpty() && colisions.first()->rtti()==15){
+                    }else*/ if(!colisions.isEmpty() &&
+                                        colisions.first()->rtti()==RTTI_LOOPMARKER){
                                 cout<<"loop marker hit bw: "<<int(getBeatDistance()/getZoomRatio())<<endl;
                             LoopMarker* temp=(LoopMarker*)colisions.first();
                             temp->setMoving(TRUE);
@@ -239,12 +262,15 @@ DrawSoundWidget::DrawSoundWidget(QWidget *parent, const char *name,SoundManager*
  }
 
     void DrawSoundWidget::contentsMouseMoveEvent( QMouseEvent * mouseEvent){
+        checkAndScroll(mouseEvent);
         handleMouseMoveBeatLine(mouseEvent);
         handleMouseMoveSelectionRectangles(mouseEvent);
         handleMouseMoveVerticalSelectionRectangles(mouseEvent);
         handleMouseMoveLoopMarkers(mouseEvent);
+        handleMouseMoveBeatRect(mouseEvent);
     }
  void DrawSoundWidget::contentsMouseReleaseEvent( QMouseEvent * mouseEvent){
+    scrollTimer->stop();
     if (mouseEvent->button()==LeftButton){
         if(mouseEvent->pos().y()<canvas->getRulerHeight()){
             emit(stopPlay());
@@ -280,16 +306,21 @@ DrawSoundWidget::DrawSoundWidget(QWidget *parent, const char *name,SoundManager*
         canvas->update();
     }
     if(BeatLine* beatline=getMovingBeatLine()) beatline->setMoving(FALSE);
+    if(LockedBeatRect* beatrect=getMovingBeatRect()) beatrect->setSelected(FALSE);
     setCursor(QCursor(Qt::Qt::ArrowCursor ));
     canvas->update();
  }
 
 
 void DrawSoundWidget::resized(){
+    updateCanvas=false;
     setPositionPointer((int)((double)playPosition/getZoomRatio()));
     updateLoopMarkers();
     updateSelectionRectangles();
     updateBeatLines();
+    updateLockedBeatRects();
+    updateCanvas=true;
+    canvas->update();
 }
 
 /*!
@@ -299,7 +330,9 @@ void DrawSoundWidget::fileLoaded()
 {
     setPositionPointer(0);
     unlockBeatLines();
-    setBeatLines(soundManager->analyse(20,4));
+    removeBeatLines();
+    removeBPMLines();
+    setBeatLines(soundManager->analyse(16,4));
     analysisFinished();
     setLoopMarkersOnMeasure(0);
     loopMarkerL->show();
@@ -354,6 +387,7 @@ void DrawSoundWidget::removeBeatLines()
                 delete beatline;
         }
         if(updateCanvas) canvas->update();
+        emit(beatLinesChanged(toArray(beatLines)));
 }
 
 void DrawSoundWidget::addBeatLine(long beat){
@@ -375,6 +409,34 @@ void DrawSoundWidget::addBeatLine(long beat){
             beatline->setX((int)((double)beat/getZoomRatio()));
             if(showBeatLinesVal) beatline->show();
             beatLines.append(beatline);
+            emit(beatLinesChanged(toArray(beatLines)));
+    }
+
+}
+
+void DrawSoundWidget::addLockedBeatLine(long beat){
+    //locks the beatline if already present
+    bool alreadyPresent=FALSE;
+    QPtrListIterator<BeatLine> it( beatLines );
+    BeatLine *beatline;
+    while ( (beatline = it.current()) != 0 ) {
+        ++it;
+        if(abs(beatline->getBeatPos()-beat)<16){
+            beatline->lock();
+            lockedBeatLines.append(beatline);
+            beatLines.remove(beatline);
+            alreadyPresent=TRUE;
+            break;
+        }
+    }
+    if(!alreadyPresent){
+        BeatLine* beatline=new BeatLine(canvas,beat);
+        beatline->setSampleValueView(sampleValueView);
+        beatline->setPen(QColor(50,255,50));
+        beatline->setX((int)((double)beat/getZoomRatio()));
+        beatline->lock();
+        if(showBeatLinesVal) beatline->show();
+        lockedBeatLines.append(beatline);
     }
 
 }
@@ -393,6 +455,7 @@ void DrawSoundWidget::setBeatLines(QMemArray<long> beats)
                     addBeatLine(beats[i]);
         }
         if(updateCanvas) canvas->update();
+        emit(beatLinesChanged(toArray(beatLines)));
         std::cout<<"beatLines: "<<beatLines.count()<<endl;
         //delete beats;
 }
@@ -718,6 +781,7 @@ void DrawSoundWidget::computeNewBPMLines(const QString & bpm_s){
 	float newBPM=bpm_s.toFloat()*soundManager->getRate()*60;
 	float oldBPM=getUsedBPM()*soundManager->getRate()*60;
 	new_to_oldBPM_ratio=newBPM/oldBPM;
+        /*
 	for (uint i=0;i<newBeatLines.count();i++){
 		delete newBeatLines.at(i);
     		newBeatLines.remove(i);
@@ -730,6 +794,7 @@ void DrawSoundWidget::computeNewBPMLines(const QString & bpm_s){
 		newBeatLines.append(beatline);
 	}
 	updateNewBeatLines();
+        */
 }
 
 
@@ -751,6 +816,28 @@ void DrawSoundWidget::unlockBeatLines()
 		lockedBeatLines.remove(beatline);
     	}
     	updateBeatLines();
+        updateLockedBeatRects();
+        emit(beatLinesChanged(toArray(beatLines)));
+        emit(lockedBeatLinesChanged(toArray(lockedBeatLines)));
+}
+
+/*!
+    \fn DrawSoundWidget::unlockBeatLines()
+ */
+void DrawSoundWidget::lockBeatLines()
+{
+    QPtrListIterator<BeatLine> it( beatLines );
+    BeatLine *beatline=0;
+    while ( (beatline = it.current()) != 0 ) {
+        ++it;
+        beatline->lock();
+        lockedBeatLines.append(beatline);
+        beatLines.remove(beatline);
+    }
+    updateBeatLines();
+    updateLockedBeatRects();
+    emit(beatLinesChanged(toArray(beatLines)));
+    emit(lockedBeatLinesChanged(toArray(lockedBeatLines)));
 }
 
 void DrawSoundWidget::reinitCanvas(){
@@ -817,7 +904,7 @@ void DrawSoundWidget::updateVerticalSelectionRectangles()
 
 	int newHeight=-(visibleHeight()*(verticalSelections.at(i)->getEndBandPos()-verticalSelections.at(i)->getStartBandPos()))/512;
 
-	verticalSelections.at(i)->setSize(this->visibleWidth(),newHeight);
+	verticalSelections.at(i)->setSize(this->width(),newHeight);
 
  cout<<"start: "<<verticalSelections.at(i)->getStartBandPos()<<" end: "<<verticalSelections.at(i)->getEndBandPos()<<" height: "<<newHeight<<"\n";
     }
@@ -841,7 +928,6 @@ void DrawSoundWidget::resample(){
 	for (uint i=0;i<lockedBeatLines.count();i++){
 			sortedPos.push_front(lockedBeatLines.at(i)->getBeatPos());
 	}
-
 	sortedPos.sort();
 	soundManager->resample(sortedPos,new_to_oldBPM_ratio);
          //zoomAll();  //problem!!
@@ -950,6 +1036,7 @@ void DrawSoundWidget::zoomChanged(){
     updateCanvas=false;
     setPositionPointer(playPosition);
     updateBeatLines();
+    updateLockedBeatRects();
     updateSelectionRectangles();
     updateVerticalSelectionRectangles();
     updateLoopMarkers();
@@ -970,7 +1057,7 @@ void DrawSoundWidget::getNearestLinePos(QPoint pos,long& sample_pos,int& x)
     if(!colisions.isEmpty()){
         QCanvasItemList::iterator it;
         for ( it = colisions.begin(); it != colisions.end(); ++it ){
-                if((*it)->rtti()==9){
+                if((*it)->rtti()==RTTI_BEATLINE){
                     BeatLine* temp=(BeatLine*)(*it);
                     x=temp->x();
                     sample_pos=temp->getBeatPos();
@@ -983,7 +1070,7 @@ void DrawSoundWidget::getNearestLinePos(QPoint pos,long& sample_pos,int& x)
 void DrawSoundWidget::contentsMoved(int x,int y){
     canvas->setPixmapXOrigin(x);
     long start_sample=x*getZoomRatio();
-    long end_sample=(x+visibleWidth())*getZoomRatio();
+    long end_sample=(x+width())*getZoomRatio();
 
     /*
     cout<<"in contentsMoved("<<x<<","<<y<<"): start_sample="<<start_sample<<" end sample="<<end_sample<<"\n";
@@ -1029,21 +1116,6 @@ long DrawSoundWidget::getSelectionEndSample()
 }
 
 
-/*!
-    \fn DrawSoundWidget::getLockedBeats()
- */
-void DrawSoundWidget::getLockedBeats(long tempLocked[])
-{
-
-    QPtrListIterator<BeatLine> it( lockedBeatLines );
-    BeatLine *beatline;
-    int count=0;
-    while ( (beatline = it.current()) != 0 ) {
-        ++it;
-        tempLocked[count]=beatline->getBeatPos();
-        count++;
-    }
-}
 
 /*!
     \fn DrawSoundWidget::getLockedBeats()
@@ -1286,6 +1358,34 @@ void DrawSoundWidget::cropped(long start,long end){
         }
     updateSelectionRectangles();
     updateVerticalSelectionRectangles();
+
+   //remove cropped beatlines
+        BeatLine *beatline;
+        QPtrListIterator<BeatLine> it( beatLines );
+        
+        while ( (beatline = it.current()) != 0 ) {
+                ++it;
+                if(beatline->getBeatPos()<start || beatline->getBeatPos()>end){
+                    beatLines.remove(beatline);
+                    delete beatline;
+                }
+                else{
+                    beatline->setSamplePos(beatline->getBeatPos()-start);
+                }
+        }
+        emit(beatLinesChanged(toArray(beatLines)));
+        QPtrListIterator<BeatLine> it2( lockedBeatLines );
+        while ( (beatline = it2.current()) != 0 ) {
+                ++it2;
+                if(beatline->getBeatPos()<start || beatline->getBeatPos()>=end){
+                    lockedBeatLines.remove(beatline);
+                    delete beatline;
+                }else{
+                    beatline->setSamplePos(beatline->getBeatPos()-start);
+                }
+        }
+        canvas->update();
+        emit(lockedBeatLinesChanged(toArray(lockedBeatLines)));
     zoomAll();
 }
 
@@ -1298,7 +1398,7 @@ void DrawSoundWidget::showBeatLines(bool tf)
     QCanvasItemList items=canvas->allItems();
     QCanvasItemList::iterator it;
     for ( it = items.begin(); it != items.end(); ++it ){
-        if ((*it)->rtti()==BeatLine::RTTI_BEATLINE){
+        if ((*it)->rtti()==RTTI_BEATLINE){
             if(tf) (*it)->show();
             else (*it)->hide();
         }
@@ -1403,8 +1503,8 @@ void DrawSoundWidget::computePosFromMouse(QMouseEvent* mouseEvent, int& pos_x, l
     QPoint pos=mouseEvent->pos();
     pos_x=pos.x();
     pos_x=pos_x<contentsX()?
-                contentsX():pos_x>contentsX()+visibleWidth()?
-                    contentsX()+visibleWidth():pos_x;
+                contentsX():pos_x>contentsX()+width()?
+                    contentsX()+width():pos_x;
     sample_pos=pos_x*getZoomRatio();
     sample_pos=sample_pos>soundManager->getFrames()?soundManager->getFrames():sample_pos;
     sample_pos=sample_pos<0?0:sample_pos;
@@ -1486,6 +1586,34 @@ BeatLine* DrawSoundWidget::getMovableBeatLine(QPoint pos)
     return 0;
 }
 
+/*!
+        \fn DrawSoundWidget::getMovableBeatRect(QPoint pos)
+ */
+LockedBeatRect* DrawSoundWidget::getMovableBeatRect(QPoint pos)
+{
+    QPtrListIterator<LockedBeatRect> it( lockedBeatRects );
+    LockedBeatRect *beatrect;
+    while ( (beatrect = it.current()) != 0 ) {
+        ++it;
+        if(beatrect->getHandle()->contains(pos)) return beatrect;
+    }
+    return 0;
+}
+
+/*!
+        \fn DrawSoundWidget::getMovingBeatRect()
+ */
+LockedBeatRect* DrawSoundWidget::getMovingBeatRect()
+{
+    QPtrListIterator<LockedBeatRect> it( lockedBeatRects );
+    LockedBeatRect *beatrect;
+    while ( (beatrect = it.current()) != 0 ) {
+        ++it;
+        if(beatrect->isSelected()) return beatrect;
+    }
+    return 0;
+}
+
 /*!
     \fn DrawSoundWidget::getMovableBeatLine(QPoint pos)
  */
@@ -1548,8 +1676,11 @@ BeatLine* DrawSoundWidget::getMovingBeatLine()
 void DrawSoundWidget::handleMouseMoveBeatLine(QMouseEvent* mouseEvent)
 {
     if(BeatLine* beatline=getMovingBeatLine()){
-        beatline->setX(mouseEvent->pos().x());
-        beatline->setSamplePos(mouseEvent->pos().x()*getZoomRatio());
+        long sample_pos=0;
+        int pos_x=0;
+        computePosFromMouse(mouseEvent,pos_x,sample_pos);
+        beatline->setX(pos_x);
+        beatline->setSamplePos(sample_pos);
         canvas->update();
     }else if(getMovableBeatLine(mouseEvent->pos())){
         setCursor(QCursor(Qt::SizeHorCursor));
@@ -1558,21 +1689,93 @@ void DrawSoundWidget::handleMouseMoveBeatLine(QMouseEvent* mouseEvent)
     }
 }
 
-void DrawSoundWidget::dragEnterEvent(QDragEnterEvent* event)
+/*!
+    \fn DrawSoundWidget::handleMousMoveBeatRect(MouseEvent* mouseEvent)
+ */
+void DrawSoundWidget::handleMouseMoveBeatRect(QMouseEvent* mouseEvent)
 {
-    event->accept(
-            QTextDrag::canDecode(event));
+    if(LockedBeatRect* beatrect=getMovingBeatRect()){
+        QString tempfilename=QString::number(beatrect->getNb()).rightJustify(8,'0').append(".")
+                                                .append(soundManager->getFileExtension());
+
+        QString orig=tempfilename;
+        orig.prepend("orig-").prepend(soundManager->getTempDir()+"/");
+
+        QString final=tempfilename;
+        final.prepend(soundManager->getTempDir()+"/");
+
+        QString ladspa=tempfilename;
+        ladspa.prepend("ladspa-").prepend(soundManager->getTempDir()+"/");
+
+
+        QStrList filelist;
+
+        soundManager->saveChunkToAs(   final,
+                                       beatrect->getStartSample(),
+                                       beatrect->getEndSample(),-1,0,SoundHolder::FOR_OUTPUT);
+        filelist.append(final);
+
+        /*
+        soundManager->saveChunkToAs(   orig,
+                                       beatrect->getStartSample(),
+                                       beatrect->getEndSample(),-1,0,SoundHolder::ORIGINAL_WAVE);
+        filelist.append(orig);
+
+        if(soundManager->getHasLADSPA()){
+            soundManager->saveChunkToAs(   ladspa,
+                                           beatrect->getStartSample(),
+                                           beatrect->getEndSample(),-1,0,SoundHolder::FOR_OUTPUT);
+            filelist.append(ladspa);
+        }
+        */
+
+        WaveDrag* waveDrag=new WaveDrag(filelist,this);
+
+        QPixmap pixmap=QPixmap::grabWidget(this);
+        QPixmap pixmap2;
+        pixmap2.resize((beatrect->getEndSample()-beatrect->getStartSample())/getZoomRatio(),
+                                        pixmap.height()-40);
+        copyBlt(&pixmap2,0,0,&pixmap,beatrect->x()-contentsX(),20,pixmap2.width(),pixmap2.height());
+
+        QWMatrix m;
+        m.scale(.5,.25);
+        QPixmap scaledPixmap = pixmap2.xForm(m);
+        waveDrag->setPixmap(scaledPixmap);
+        waveDrag->dragMove();
+        beatrect->setSelected(FALSE);
+        canvas->update();
+    }
 }
 
-void DrawSoundWidget::dropEvent(QDropEvent* event)
+void DrawSoundWidget::contentsDragEnterEvent(QDragEnterEvent* event)
 {
-    QString text;
-
-    if ( QTextDrag::decode(event, text) ) {
-        emit(receivedEnvelope(event->pos(),text));
+    cout<<"contentsDragEnterEvent\n";
+    if(lockedBeatLines.count()>0 && QUriDrag::canDecode(event)){
+        QStringList list;
+        QUriDrag::decodeLocalFiles(event,list);
+        cout<<"Dragged file: "<<list.front()<<endl;
+        event->accept(soundManager->canOpen(list.front()));
     }
 }
 
+void DrawSoundWidget::contentsDragMoveEvent(QDragMoveEvent* event)
+{
+    if(event->isActionAccepted()){
+        QPoint pos=event->pos();
+        QCanvasItemList colisions=canvas->collisions(pos);
+        cout<<"drag pos: "<<pos.x()<<endl;
+    }
+}
+
+void DrawSoundWidget::contentsDropEvent(QDropEvent* event)
+{
+        int insertpos=event->pos().x();
+        QStringList list;
+        QUriDrag::decodeLocalFiles(event,list);
+        soundManager->insertFileAt(list.front(),0);
+        cout<<"wavefile dropped\n";
+}
+
 
 
 
@@ -1590,3 +1793,183 @@ void DrawSoundWidget::removeSelectionRectangles()
     selection->setEndSamplePosition(0);
     if(updateCanvas) canvas->update();
 }
+
+
+/*!
+    \fn DrawSoundWidget::checkAndScroll(int x)
+ */
+void DrawSoundWidget::checkAndScroll(QMouseEvent* event)
+{
+    // start autoscrolling if necessary
+    storedMouse=event;
+    scrollPos=storedMouse->pos();
+    if(((abs(scrollPos.x()-(contentsX()+width()))<20) && (contentsX()+width()<contentsWidth())) ||
+        ((abs(scrollPos.x()-contentsX())<20) &&(contentsX()>20))){
+        if(!scrollTimer->isActive()) scrollTimer->start(1);
+    }else{
+        scrollTimer->stop();
+    }
+}
+
+
+/*!
+    \fn DrawSoundWidget::scroll()
+ */
+void DrawSoundWidget::scroll()
+{
+    bool scrolled=FALSE;
+    int rightScrollArea=scrollPos.x()-(contentsX()+width());
+    int leftScrollArea=scrollPos.x()-contentsX();
+    if(abs(rightScrollArea)<20){
+        int scrollAmount=abs(rightScrollArea)<10?8:4;
+        scrollBy(scrollAmount,0);
+        scrollPos.rx()+=scrollAmount;
+        scrolled=TRUE;
+    }else if(abs(leftScrollArea)<20){
+        int scrollAmount=abs(leftScrollArea)<10?8:4;
+        scrollBy(-scrollAmount,0);
+        scrollPos.rx()-=scrollAmount;
+        scrolled=TRUE;
+    }
+    if(scrolled){
+        handleMouseMoveBeatLine(storedMouse);
+        handleMouseMoveSelectionRectangles(storedMouse);
+        handleMouseMoveVerticalSelectionRectangles(storedMouse);
+        handleMouseMoveLoopMarkers(storedMouse);
+    }
+}
+
+
+/*!
+    \fn DrawSoundWidget::toArray(QPtrList<BeatLine> beatlines)
+ */
+QValueList<long> DrawSoundWidget::toArray(QPtrList<BeatLine> beatlines)
+{
+    QValueList<long> returnArray;
+    QPtrListIterator<BeatLine> it( beatlines );
+    BeatLine *beatline;
+    while ( (beatline = it.current()) != 0 ) {
+        ++it;
+        returnArray.append(beatline->getBeatPos());
+    }
+    qHeapSort(returnArray);
+    return returnArray;
+}
+
+
+/*!
+    \fn DrawSoundWidget::findNextLockedBeatLine(BeatLine bl)
+ */
+BeatLine* DrawSoundWidget::findNextLockedBeatLine(BeatLine* bl)
+{
+    lockedBeatLines.sort();
+    QPtrListIterator<BeatLine> it( lockedBeatLines );
+    BeatLine *beatline;
+    while ( (beatline = it.current()) != 0 ) {
+        ++it;
+        if (beatline->getBeatPos()>bl->getBeatPos() && beatline->locked()) return beatline;
+    }
+    return 0;
+}
+
+
+/*!
+    \fn DrawSoundWidget::getLockedBeatList()
+ */
+QValueList<long> DrawSoundWidget::getLockedBeatList()
+{
+    return toArray(lockedBeatLines);
+}
+
+
+/*!
+    \fn DrawSoundWidget::updateLockedBeatRects()
+ */
+void DrawSoundWidget::updateLockedBeatRects()
+{
+
+    lockedBeatLines.sort();
+    lockedBeatRects.clear();
+    QPtrListIterator<BeatLine> it( lockedBeatLines );
+    BeatLine *beatline,*beatline2;
+    int color=0;
+    int count=0;
+    while ( (beatline = it.current()) != 0 ) {
+        ++it;
+        beatline2=it.current();
+        if(beatline2!=0){
+            LockedBeatRect* lr=new LockedBeatRect(canvas,
+                                                    beatline,beatline2);
+            lr->setNb(count);
+            lr->setColor(color);
+            lr->show();
+            lockedBeatRects.append(lr);
+            color=(color+1)%2;
+            count++;
+        }
+    }
+    if(updateCanvas) canvas->update();
+
+
+}
+
+
+/*!
+    \fn DrawSoundWidget::setLockedBeatLines(QValueList <long> lbl)
+ */
+void DrawSoundWidget::setLockedBeatLines(QValueList <long> lbl)
+{
+    for (int i=0;i<lbl.count();i++){
+        addLockedBeatLine(lbl[i]);
+    }
+    updateCanvas=FALSE;
+    updateBeatLines();
+    updateLockedBeatRects();
+    updateCanvas=TRUE;
+    canvas->update();
+    emit(lockedBeatLinesChanged(toArray(lockedBeatLines)));
+}
+
+
+/*!
+    \fn DrawSoundWidget::getLeftLoopMarker()
+ */
+LoopMarker* DrawSoundWidget::getLeftLoopMarker()
+{
+    return loopMarkerL;
+}
+
+
+/*!
+    \fn DrawSoundWidget::getRightLoopMarker()
+ */
+LoopMarker* DrawSoundWidget::getRightLoopMarker()
+{
+    return loopMarkerR;
+}
+
+
+/*!
+    \fn DrawSoundWidget::getBeatList()
+ */
+QValueList <long> DrawSoundWidget::getBeatList()
+{
+    QValueList<long> result=toArray(beatLines)+toArray(lockedBeatLines);
+    qHeapSort(result);
+    return result;
+}
+
+
+/*!
+    \fn DrawSoundWidget::getAssignableBeatLine(QPoint pos)
+ */
+BeatLine* DrawSoundWidget::getAssignableBeatLine(QPoint pos)
+{
+    QPtrListIterator<BeatLine> it2( lockedBeatLines );
+    BeatLine *beatline;
+    while ( (beatline = it2.current()) != 0 ) {
+            ++it2;
+            if(beatline->getMidiNoteHandle()->contains(pos)) return beatline;
+    }
+    return 0;
+}
