@@ -20,7 +20,7 @@
 #include "drawsoundwidgetabstract.h"
 
 DrawSoundWidgetAbstract::DrawSoundWidgetAbstract(QWidget *parent, const char *name, SoundManager* sm)
- : QCanvasView(parent,name,WNoAutoErase)
+    : QCanvasView(parent,name,Qt::WNoAutoErase)
 {
     soundManager=sm;
     canvas=new WaveCanvas(this->viewport());
@@ -76,7 +76,7 @@ long DrawSoundWidgetAbstract::zoomToSamplePos(long start,long end)
     long temp_zoomRatio=long(float(diff)/float(width()));
 std::cout<<"["<<name()<<"]: temp_zoom: "<<temp_zoomRatio<<" visibleWidth: "<<visibleWidth()<<" s-e:"<<start<<"-"<<end<<"\n";
     if(temp_zoomRatio<1) temp_zoomRatio=1;
-    setZoomRatio(temp_zoomRatio);
+    setZoomRatio(temp_zoomRatio,FALSE);
     center(mid/zoomRatio,canvas->height()/2);
     return zoomRatio;
 }
@@ -128,7 +128,7 @@ void DrawSoundWidgetAbstract::forceRepaint(){
     //called after crop
     //called when resizing window
     if(soundManager->hasSound()){
-        cout<<"in "<<name()<<" forceRepaint()\n";
+        //cout<<"in "<<name()<<" forceRepaint()\n";
         canvas->setVisibleWidth(width());
         canvas->forceRepaint();//0,soundManager->getFrames());
     }
@@ -138,6 +138,7 @@ void DrawSoundWidgetAbstract::forceRepaint(long start_sample,long end_sample){
     if(soundManager->hasSound()){
         assert(start_sample>=0 &&
                 end_sample<=soundManager->getFrames() && end_sample>start_sample);
+        //cout<<"in "<<name()<<" forceRepaint("<<start_sample<<","<<end_sample<<")\n";
         canvas->forceRepaint(start_sample,end_sample);
     }
 }
@@ -157,7 +158,7 @@ long DrawSoundWidgetAbstract::checkSamplePosition(long sample_pos)
          1) Changes zoom ratio
          2) Resizes the canvas,
 */
-void DrawSoundWidgetAbstract::setZoomRatio(long _zr){
+void DrawSoundWidgetAbstract::setZoomRatio(long _zr,bool repaint){
     cout<<"in "<<name()<<" setZoomRatio()\n";
     zoomRatio=_zr;
     canvas->setZoomRatio(zoomRatio);
@@ -167,9 +168,10 @@ void DrawSoundWidgetAbstract::setZoomRatio(long _zr){
     //end on init
     canvas->resize(soundManager->getFrames()/zoomRatio,c_height);
     canvas->setPixmapXOrigin(0);
-    zapWaveCanvasBuffers();
+    zapWaveCanvasBuffers(repaint);
     zoomChanged();
     resized();
+
     oldVisibleSize=getLastVisibleSample()-getFirstVisibleSample();
 }
 
@@ -177,11 +179,11 @@ void DrawSoundWidgetAbstract::setZoomRatio(long _zr){
 /*!
     \fn DrawSoundWidgetAbstract::zapWaveCanvasBuffers()
  */
-void DrawSoundWidgetAbstract::zapWaveCanvasBuffers()
+void DrawSoundWidgetAbstract::zapWaveCanvasBuffers(bool repaint)
 {
     cout<<"in "<<name()<<" zapWaveCanvasBuffers()\n";
     canvas->zapBuffers();
-    forceRepaint();
+    if (repaint) forceRepaint();
 }
 
 
@@ -190,6 +192,7 @@ void DrawSoundWidgetAbstract::zapWaveCanvasBuffers()
  */
 void DrawSoundWidgetAbstract::zapWaveCanvasBuffers(long start, long end)
 {
+    cout<<"in "<<name()<<" zapWaveCanvasBuffers("<<start<<","<<end<<")\n";
     canvas->zapBuffers(start,end);
     forceRepaint(start,end);
 }
