@@ -42,7 +42,7 @@ protected:
 public:
 
     long getZoomRatio();
-    void setZoomRatio(long zr);
+    void setZoomRatio(long zr, bool repaint=TRUE);
     long getFirstVisibleSample();
     long getLastVisibleSample();
     long checkSamplePosition(long);
@@ -54,6 +54,7 @@ protected:
     WaveCanvas* canvas;
     SoundManager* soundManager;
     QSize contentsSize;
+    long oldVisibleSize;
 
     void resizeEvent(QResizeEvent*);
 
@@ -68,7 +69,7 @@ public slots:
     void forceRepaint();
     void forceRepaint(long,long);
     long zoomToSamplePos(long,long);
-    void zapWaveCanvasBuffers();
+    void zapWaveCanvasBuffers(bool repaint=TRUE);
     void zapWaveCanvasBuffers(long start, long end);
 
 };
