@@ -44,6 +44,9 @@ public:
     void setApplyPolicy(int);
     void reinit();
     QSize sizeHint () const;
+    LADSPAEffect* getLadspa();
+    EffectPortFrame* getPortFrame(int portNo);
+    void updateDrawModeButton();
 
 private:
     LADSPAEffect* effect;
@@ -72,11 +75,21 @@ public slots:
     void switchOnReleaseApplyPolicy();
     void switchOnChangeApplyPolicy();
     void changeDrawMode(EffectPortFrame::DrawMode dm);
+    void lockedBeatLinesChanged(QValueList <long>);
+    void beatLinesChanged(QValueList <long>);
+    void setSplineData(int port_no, QValueList<SplinePoint>);
+    void setPolylineData(int port_no, QValueList<SortablePoint>);
+    void reinitLADSPAValues();
 
 
 signals:
     void applyMe(LADSPAEffect*);
     void applyMe(LADSPAEffect*,long,long);
+    void lockedBeatLinesChangedS(QValueList <long>);
+    void beatLinesChangedS(QValueList <long>);
+    void zoomRatioChangedS(long _zr);
+    void applyPolicyChanged(int);
+    void cropS(long,long);
 
 
 protected:
