@@ -74,24 +74,27 @@ Freecycle::Freecycle()
     openIcon = QPixmap( fileopen );
     saveIcon = QPixmap( filesave );
     QMimeSourceFactory::defaultFactory()->setPixmap( "fileopen", openIcon );
-    QPopupMenu * file = new QPopupMenu( this );
-    menuBar()->insertItem( tr("&File"), file );
+    filePopupMenu = new QPopupMenu( this );
+    menuBar()->insertItem( tr("&File"), filePopupMenu );
 
-    file->insertItem( openIcon, tr("&Open..."),
+    filePopupMenu->insertItem( openIcon, tr("&Open Wave..."),
 			   this, SLOT(choose()), CTRL+Key_O );
 
-    file->insertItem( saveIcon, tr("&Save"),
+    idsavedialog=filePopupMenu->insertItem( saveIcon, tr("&Save Wave"),
 			   this, SLOT(save()), CTRL+Key_S );
 
-    file->insertItem( tr("Save &As..."), this, SLOT(saveAs()) );
-    file->insertItem( tr("Save Chunks..."), this, SLOT(saveChunks()) );
+    idsaveasdialog= filePopupMenu->insertItem( tr("Save Wave &As..."), this, SLOT(saveAs()) );
+    idsavechunksdialog=filePopupMenu->insertItem( tr("Save Audio Chunks..."), this, SLOT(saveChunks()) );
+    idsaveprojectdialog=filePopupMenu->insertItem( tr("Save Project..."), this, SLOT(saveProject()) );
+    idloadprojectdialog=filePopupMenu->insertItem( tr("Load Project..."), this, SLOT(loadProject()) );
 
-    file->insertSeparator();
 
-    file->insertItem( tr("&Close"), this, SLOT(close()), CTRL+Key_W );
+    filePopupMenu->insertSeparator();
+
+    filePopupMenu->insertItem( tr("&Close"), this, SLOT(close()), CTRL+Key_W );
 
     //file->insertItem( tr("&Quit"), qApp, SLOT( closeAllWindows() ), CTRL+Key_Q );
-    file->insertItem( tr("&Quit"), this, SLOT( close()), CTRL+Key_Q );
+    filePopupMenu->insertItem( tr("&Quit"), this, SLOT( close()), CTRL+Key_Q );
 
     menuBar()->insertSeparator();
 
@@ -364,9 +367,12 @@ Freecycle::Freecycle()
 
 
 
+
     connect(newBPM,
                     SIGNAL(valueChanged(const QString &)),
                     drawSoundWidget,SLOT(computeNewBPMLines(const QString &)));
+
+
     connect(resampleButton,
                       SIGNAL(clicked()),drawSoundWidget,SLOT(resample()));
     MySplitter *small_waveAndSpectrum = new MySplitter(Qt::Horizontal, big_and_small_wave );
@@ -454,11 +460,23 @@ Freecycle::Freecycle()
     helpPopupMenu->insertItem( tr("About"),this,SLOT(about()));
     menuBar()->insertItem( tr("&Help"), helpPopupMenu,5);
 
+
     openFileDialog=new MyOpenFileDialog(soundManager,soundPlayer,fileManager);
     saveFileDialog=new MySaveFileDialog();
+    projectManager=new ProjectManager(soundManager,
+                                                                             envelopeControllerWidget->getEnvData());
+    projectManager->setLoopMarkers(drawSoundWidget->getLeftLoopMarker(),
+                                                                    drawSoundWidget->getRightLoopMarker());
 
+    connect(projectManager,SIGNAL(loadFile(const QString& )), this, SLOT(load(const QString& )));
+    connect(projectManager,SIGNAL(envelopeDataChanged()),
+                envelopeControllerWidget, SLOT(envDataChanged()));
+    connect(projectManager,SIGNAL(addLadspa(int)),this,SLOT(addEffectFrame(int)));
+    connect(projectManager,SIGNAL(addLockedBeatlines(QValueList<long>)),
+            drawSoundWidget,SLOT(setLockedBeatLines(QValueList <long>)));
 
-
+    saveProjectDialog=new MySaveProjectDialog(projectManager);
+    loadProjectDialog=new MyLoadProjectDialog(projectManager);
 
     QAccel *accelerator = new QAccel( this );        // create accels for myWindow
     accelerator->connectItem( accelerator->insertItem(Key_Space),
@@ -479,8 +497,13 @@ Freecycle::Freecycle()
 
     connect(drawSoundWidget,SIGNAL(beatLinesChanged(QValueList< long > )),
         soundManager,SLOT(beatLinesChanged(QValueList< long > )));
-connect(drawSoundWidget,SIGNAL(lockedBeatLinesChanged(QValueList< long > )),
+    connect(drawSoundWidget,SIGNAL(lockedBeatLinesChanged(QValueList< long > )),
         soundManager,SLOT(lockedBeatLinesChanged(QValueList< long > )));
+
+    filePopupMenu->setItemEnabled(idsavedialog,FALSE);
+    filePopupMenu->setItemEnabled(idsaveasdialog,FALSE);
+    filePopupMenu->setItemEnabled(idsavechunksdialog,FALSE);
+    filePopupMenu->setItemEnabled(idsaveprojectdialog,FALSE);
 }
 
 void Freecycle::changeZoom(int value){
@@ -590,6 +613,11 @@ void Freecycle::load( const QString &fileName )
         menuBar()->setItemEnabled(4,TRUE);
         menuBar()->setItemEnabled(5,TRUE);
 
+        filePopupMenu->setItemEnabled(idsavedialog,TRUE);
+        filePopupMenu->setItemEnabled(idsaveasdialog,TRUE);
+        filePopupMenu->setItemEnabled(idsavechunksdialog,TRUE);
+        filePopupMenu->setItemEnabled(idsaveprojectdialog,TRUE);
+
         if(effectFrame) effectFrame->reinit();
         if(!topBox->isVisible()) topBox->show();
         if(!playAndBeatLinesControls->isVisible()) playAndBeatLinesControls->show();
@@ -730,11 +758,13 @@ void Freecycle::saveChunks()
                 }
             }
             cout<<"Export bits per sample: "<<saveFileDialog->getExportBitsPerSample()<<" code: "<<soundManager->toBpsCode(saveFileDialog->getExportBitsPerSample())<<"\n";
+            /*
             if(saveFileDialog->getAttackTime()!=0){
                 Envelope* env=new Envelope();
                 env->setEnvDurationAndSamplerate(saveFileDialog->getAttackTime(),soundManager->getRate());
                 soundManager->addPostProcessEffect(env);
             }
+            */
             QStringList* filenames=
                 soundManager->saveChunksTo(fn,beatlines.data(),beatlines.size(),
                                      soundManager->toBpsCode(saveFileDialog->getExportBitsPerSample()));
@@ -883,10 +913,13 @@ void Freecycle::removeEffect(){
         soundManager->applyEnvelope();
     else soundManager->zapInstantEBuffer();
     if(effectFrame){
-        effectFrame->close();
+        effectFrame->close(TRUE);
+        effectFrame=0;
     }
     drawSoundWidget->zapWaveCanvasBuffers();
     drawAllSoundWidget->zapWaveCanvasBuffers();
+    projectManager->setLadspa(0);
+    soundManager->getEffects()->setCurrent(0);
 }
 
 void Freecycle::addEffectFrame(int uniqueId){
@@ -894,6 +927,7 @@ void Freecycle::addEffectFrame(int uniqueId){
     removeEffect();
     soundManager->setHasLadspa(TRUE);
     LADSPAEffect* temp=soundManager->getEffects()->getEffect(uniqueId);
+    soundManager->getEffects()->setCurrent(temp);
     effectFrame=new EffectFrame(temp,big_and_small_wave_and_effects);
     big_and_small_wave_and_effects->setResizeMode(effectFrame,QSplitter::Stretch);
     effectFrame->setZoomRatio(drawSoundWidget->getZoomRatio());
@@ -907,8 +941,42 @@ void Freecycle::addEffectFrame(int uniqueId){
     connect(drawSoundWidget,
                     SIGNAL(contentsMoving(int,int)),
                     effectFrame,SLOT(setContentsPos(int,int)));
+    connect(soundManager,SIGNAL(reinitLADSPAValues()),effectFrame,SLOT(reinitLADSPAValues()));
+    /*
+    connect(drawSoundWidget,SIGNAL(beatLinesChanged(QValueList< long > )),
+            effectFrame,SIGNAL(beatLinesChanged(QValueList< long > )));
+    */
+    connect(drawSoundWidget,SIGNAL(lockedBeatLinesChanged(QValueList< long > )),
+            effectFrame,SLOT(lockedBeatLinesChanged(QValueList< long > )));
+
+    connect(soundManager,SIGNAL(cropped(long, long )),effectFrame,SIGNAL(cropS(long, long )));
+    effectFrame->lockedBeatLinesChanged(drawSoundWidget->getLockedBeatList());
+
     effectFrame->show();
+
+    //load polylines and splines, if any
+    if(projectManager->getPolylines().count()>0){
+        ProjectManager::polylinesMapT polylines=projectManager->getPolylines();
+        ProjectManager::polylinesMapT::Iterator it;
+        for ( it = polylines.begin(); it != polylines.end(); ++it ) {
+            effectFrame->setPolylineData(it.key(),it.data());
+        }
+    }
+
+    if(projectManager->getSplines().count()>0){
+        ProjectManager::splinesMapT splines=projectManager->getSplines();
+        ProjectManager::splinesMapT::Iterator it;
+        for ( it = splines.begin(); it != splines.end(); ++it ) {
+            effectFrame->setSplineData(it.key(),it.data());
+        }
+    }
+    projectManager->clearPolylinesSplines();
+    effectFrame->updateDrawModeButton();
+    //end load polylines and splines, if any
+
+
     effectFrame->apply();
+    projectManager->setLadspa(effectFrame);
 }
 
 void Freecycle::updateNbFramesLabel(){
@@ -1125,3 +1193,34 @@ void Freecycle::numPad1Pressed()
 {
     soundPlayer->setPosition(0);
 }
+
+
+/*!
+    \fn Freecycle::saveProject()
+ */
+void Freecycle::saveProject()
+{
+    QString fn=NULL;
+    if ( saveProjectDialog->exec() == QDialog::Accepted ){
+        fn=saveProjectDialog->selectedFile();
+        projectManager->setFilename(fn);
+        projectManager->setLockedBeatLines(
+                drawSoundWidget->getLockedBeatList());
+        projectManager->saveProject();
+    }
+}
+
+
+/*!
+    \fn Freecycle::loadProject()
+ */
+void Freecycle::loadProject()
+{
+    QString fn=NULL;
+    if ( loadProjectDialog->exec() == QDialog::Accepted ){
+            fn=loadProjectDialog->selectedFile();
+            projectManager->loadProject(fn);
+            drawSoundWidget->analysisFinished(); //force bpm computation based on loaded beatlines
+    }
+
+}
