@@ -43,7 +43,6 @@ LADSPAEffect::LADSPAEffect(const LADSPA_Descriptor* _desc,QObject *parent, const
     connectors=new CustomEffects();
     nbFrames=0;
     portInitDone=FALSE;
-    usesDoublePluginVal=FALSE;
 }
 
 
@@ -147,9 +146,9 @@ void LADSPAEffect::cleanup()
  */
 void LADSPAEffect::activate()
 {
-    if(descriptor->activate && plugin_handle_1){
+    if(descriptor->activate){
         descriptor->activate(plugin_handle_1);
-        if(usesDoublePlugin() && plugin_handle_2)descriptor->activate(plugin_handle_2);
+        if(usesDoublePlugin())descriptor->activate(plugin_handle_2);
     }
 }
 
