@@ -399,25 +399,3 @@ void LADSPAPort::crop(long start, long end)
     valuesOverTime=tempVOT;
     tempVOT=0;
 }
-
-
-/*!
-    \fn LADSPAPort::insert(long start, long amount)
- */
-void LADSPAPort::insert(long start, long amount)
-{
-    cout<<"inserting VOT\n";
-    int length=(getNbFrames())/1024; //nb frames is already updated by nbFramesChanged(long) signal..I hope..
-    float* tempVOT=new float[length];
-    float* insertedVOT=new float[amount/1024];
-    for (int i=0;i<amount;i++){
-        insertedVOT[i]=val;
-    }
-    if(start>0)
-        std::memcpy(tempVOT,valuesOverTime,sizeof(float)*int(start/1024));
-    std::memcpy(&tempVOT[int(start/1024)],insertedVOT,sizeof(float)*amount);
-    std::memcpy(&tempVOT[int((start+amount)/1024)],&valuesOverTime[int(start/1024)],sizeof(float)*(getNbFrames()-start)/1024);
-    zaparr(valuesOverTime);
-    valuesOverTime=tempVOT;
-    tempVOT=0;
-}
