@@ -27,7 +27,6 @@ ProjectManager::ProjectManager(SoundManager* sm, EnvelopeData* ed,QObject *paren
     envelopeData=ed;
     leftLoopMarker=0;
     rightLoopMarker=0;
-    filename="";
 }
 
 
@@ -91,9 +90,6 @@ void ProjectManager::saveProject()
     QString tempDir=soundManager->getTempDir()+"/"+QFileInfo(filename).baseName();
     QDir dir(tempDir);
     dir.mkdir(tempDir);
-    
-    FileManager::purgeDir(tempDir);
-    
     QStringList wavefilenames=saveWaveBuffers();
     QDomDocument d;
     QDomElement freecycle_project=d.createElement("freecycle");
@@ -102,10 +98,6 @@ void ProjectManager::saveProject()
     QDomAttr releaseAttr=d.createAttribute("release");
     releaseAttr.setValue(QString(release_no));
     freecycle_project.setAttributeNode(releaseAttr);
-    
-    QDomAttr bpmModifierAttr=d.createAttribute("bpm-modifier");
-    bpmModifierAttr.setValue(bpmModifier);
-    freecycle_project.setAttributeNode(bpmModifierAttr);
 
     if(leftLoopMarker && rightLoopMarker){
         freecycle_project.appendChild(loopMarkersToXML(leftLoopMarker, rightLoopMarker));
@@ -118,10 +110,6 @@ void ProjectManager::saveProject()
         freecycle_project.appendChild(lockedBLToXML(lockedBeatLines));
     if(effectFrame!=0)
         freecycle_project.appendChild(ladspaToXML(effectFrame));
-    if(lockedBeatRects.count()>0){
-        freecycle_project.appendChild(stacksToXML(lockedBeatRects));
-        saveStackElementWaves(tempDir,lockedBeatRects);
-    }
 
     QString projectfilename=tempDir;
     QFile file(projectfilename.append("/project.xml"));
@@ -145,19 +133,23 @@ void ProjectManager::saveProject()
     cout<<"starting: "<<arg_<<endl;
 
     proc.addArgument("tar");
-    proc.addArgument("czf");
-    proc.addArgument(savefile.name());
+    proc.addArgument("cz");
     proc.addArgument("-C");
     proc.addArgument(dir.path()+"/");
     proc.addArgument(QFileInfo(filename).baseName()+"/");
-    
+    proc.addArgument("-f");
+    proc.addArgument(savefile.name());
 
 
 
     proc.start();
     while(proc.isRunning()) sleep(10);
-    
-    FileManager::deleteDir(tempDir);
+
+    dir.remove(projectfilename);
+    for (int i=0;i<wavefilenames.count();i++){
+        dir.remove(wavefilenames[i]);
+    }
+    dir.rmdir(tempDir);
 
 
 
@@ -176,13 +168,11 @@ void ProjectManager::setFilename(QString fn)
 
 
 /*!
-    \fn ProjectManager::setLockedBeatLines(QValueList<beatline_data> lbd)
+    \fn ProjectManager::setLockedBeatLines(QValueList<long> lbl)
  */
-void ProjectManager::setLockedBeatLines(QValueList<beatline_data> lbd)
+void ProjectManager::setLockedBeatLines(QValueList<long> lbl)
 {
-    
-    lockedBeatLines.clear();
-    lockedBeatLines=lbd;
+    lockedBeatLines=lbl;
 }
 
 
@@ -261,30 +251,23 @@ QDomNode ProjectManager::envelopeToXML(EnvelopeData* envData)
 
 
 /*!
-    \fn ProjectManager::lockedBLToXML(QValueList <beatline_data> lockedBL)
+    \fn ProjectManager::lockedBLToXML(QValueList <long> lockedBL)
  */
-QDomNode ProjectManager::lockedBLToXML(QValueList <beatline_data> lockedBL)
+QDomNode ProjectManager::lockedBLToXML(QValueList <long> lockedBL)
 {
     QDomDocument d;
     QDomElement beatlinesDom=d.createElement("beatlines");
     d.appendChild(beatlinesDom);
 
     for (int i=0;i<lockedBL.count();i++){
-        QDomElement beatlineE=d.createElement("beatline");
+        QDomElement beatline=d.createElement("beatline");
         QDomAttr lockedAttr=d.createAttribute("locked");
         lockedAttr.setValue("1");
-        beatlineE.setAttributeNode(lockedAttr);
-        
-        
+        beatline.setAttributeNode(lockedAttr);
         QDomAttr positionAttr=d.createAttribute("position");
-        positionAttr.setValue(QString::number(lockedBL[i].position));
-        beatlineE.setAttributeNode(positionAttr);
-        if(lockedBL[i].midiNote!=-1){
-            QDomAttr midiAttr=d.createAttribute("midiNote");
-            midiAttr.setValue(QString::number(lockedBL[i].midiNote));
-            beatlineE.setAttributeNode(midiAttr);
-        }
-        beatlinesDom.appendChild(beatlineE);
+        positionAttr.setValue(QString::number(lockedBL[i]));
+        beatline.setAttributeNode(positionAttr);
+        beatlinesDom.appendChild(beatline);
     }
     return d;
 }
@@ -504,13 +487,12 @@ void ProjectManager::setLadspa(EffectFrame* ef)
 /*!
     \fn ProjectManager::loadProject(QString filename)
  */
-void ProjectManager::loadProject(QString fn)
+void ProjectManager::loadProject(QString filename)
 {
 
-    setFilename(fn);
     clearPolylinesSplines();
 
-    cout<<"Filename: "<<filename<<endl;    
+    cout<<"Filename: "<<filename<<endl;
     QFile file(filename);
     QFileInfo finfo(filename);
 
@@ -563,6 +545,14 @@ void ProjectManager::loadProject(QString fn)
         return;
     }
     projectFile.close();
+    if(filelist.count()<=6){ //we don't want to rm -r /, are we?
+        for (int i=0;i<filelist.count();i++){
+            QFile file(uncompressedDir.path()+"/"+filelist[i]);
+            file.remove();
+        }
+        uncompressedDir.rmdir(uncompressedDir.path());
+    }
+
     if(doc.elementsByTagName("ladspa").count()!=0){
         xmlToLADSPA(doc.elementsByTagName("ladspa").item(0));
     }
@@ -576,16 +566,7 @@ void ProjectManager::loadProject(QString fn)
     if(doc.elementsByTagName("loop").count()!=0){
         xmlToLoopMarkers(doc.elementsByTagName("loop").item(0),leftLoopMarker,rightLoopMarker);
     }
-    if(doc.elementsByTagName("stacks").count()!=0){
-        xmlToStacks(doc.elementsByTagName("stacks").item(0));
-    }
-    if(!doc.elementsByTagName("freecycle").item(0).attributes().namedItem("bpm-modifier").isNull()){
-        QString bpmModifier=
-    doc.elementsByTagName("freecycle").item(0).attributes().namedItem("bpm-modifier").toAttr().value();
-        emit(bpmModifierChangeS(bpmModifier));
-    }
-    
-    FileManager::deleteDir(uncompressedDir.path());
+
 }
 
 
@@ -716,16 +697,12 @@ void ProjectManager::xmlToLADSPA(QDomNode xml)
 void ProjectManager::xmlToLBL(QDomNode xml)
 {
     if(!xml.isNull()){
-        QValueList <beatline_data> positions;
+        QValueList <long> positions;
         QDomNodeList beatlines=xml.childNodes();
         for (int i=0;i<beatlines.count();i++){
             QDomNode beatline=beatlines.item(i);
-            beatline_data bld;
-            bld.position=beatline.attributes().namedItem("position").toAttr().value().toLong();
-            bld.midiNote=beatline.attributes().namedItem("midiNote").isNull()?-1:
-                            beatline.attributes().namedItem("midiNote").toAttr().value().toInt();
-            bld.locked=1;
-            positions.append(bld);
+            long position=beatline.attributes().namedItem("position").toAttr().value().toLong();
+            positions.append(position);
         }
         emit(addLockedBeatlines(positions));
     }
@@ -858,210 +835,3 @@ void ProjectManager::xmlToLoopMarkers(QDomNode xml, LoopMarker* l, LoopMarker* r
     l->setSamplePosition(left_pos);
     r->setSamplePosition(right_pos);
 }
-
-
-/*!
-    \fn ProjectManager::getFilename()
- */
-QString ProjectManager::getFilename()
-{
-    return filename;
-}
-
-
-/*!
-    \fn ProjectManager::stacksToXML()
- */
-QDomNode ProjectManager::stacksToXML(LockedBeatRectList lbrl)
-{
-    QPtrListIterator<LockedBeatRect> it( lbrl );
-    LockedBeatRect *beatrect;
-    QDomDocument d;
-    QDomElement stacksDom=d.createElement("stacks");
-    d.appendChild(stacksDom);
-    while ( (beatrect = it.current()) != 0 ) {
-        ++it;
-        if(beatrect->getSampleNumberDisplays().count()>0){
-            stacksDom.appendChild(stackToXML(beatrect->getSampleNumberDisplays(),
-                    beatrect->getStartSample(),beatrect->getEndSample()));
-        }
-        
-    }
-    return d;
-}
-
-
-/*!
-    \fn ProjectManager::setLockedBeatRects(LockedBeatRectList lbrl)
- */
-void ProjectManager::setLockedBeatRects(LockedBeatRectList lbrl)
-{
-    lockedBeatRects=lbrl;
-}
-
-
-/*!
-    \fn ProjectManager::stackToXML(QPtrList <SampleNumberDisplay> snds, long start, long end)
- */
-QDomNode ProjectManager::stackToXML(QPtrList <SampleNumberDisplay> snds, long start, long end)
-{
-    QDomDocument d;
-    QDomElement stackDom=d.createElement("stack");
-    d.appendChild(stackDom);
-    
-    QDomAttr leftAttr=d.createAttribute("left");
-    leftAttr.setValue(QString::number(start));
-    stackDom.setAttributeNode(leftAttr);
-    
-    QDomAttr rightAttr=d.createAttribute("right");
-    rightAttr.setValue(QString::number(end));
-    stackDom.setAttributeNode(rightAttr);
-    
-    QPtrListIterator<SampleNumberDisplay> it( snds );
-    SampleNumberDisplay *snd;
-    while ( (snd = it.current()) != 0 ) {
-        ++it;
-        QDomElement stackElementDom=d.createElement("stackElement");
-        stackDom.appendChild(stackElementDom);
-        
-        QDomAttr filenameAttr=d.createAttribute("filename");
-        filenameAttr.setValue(QFileInfo(snd->getAssignedFile()).fileName());
-        stackElementDom.setAttributeNode(filenameAttr);
-        
-        QDomAttr indexAttr=d.createAttribute("index");
-        indexAttr.setValue(QString::number(snd->getNumber()));
-        stackElementDom.setAttributeNode(indexAttr);
-        
-        QDomAttr sceneAttr=d.createAttribute("scene");
-        sceneAttr.setValue(QString::number(snd->getScene()));
-        stackElementDom.setAttributeNode(sceneAttr);
-        
-        if(snd->getCurrent()){
-            QDomAttr currentAttr=d.createAttribute("current");
-            currentAttr.setValue("1");
-            stackElementDom.setAttributeNode(currentAttr);
-        }
-    }
-    
-    return d;
-}
-
-
-/*!
-    \fn ProjectManager::saveStackElementWaves(QString dir, LockedBeatRectList lbrl)
- */
-void ProjectManager::saveStackElementWaves(QString dir, LockedBeatRectList lbrl)
-{
-    QPtrListIterator<LockedBeatRect> it( lbrl );
-    LockedBeatRect *beatrect;
-    QStringList files;
-    while ( (beatrect = it.current()) != 0 ) {
-        ++it;
-        QPtrList <SampleNumberDisplay> snds=beatrect->getSampleNumberDisplays();
-        if(snds.count()>0){
-            QPtrListIterator<SampleNumberDisplay> it2( snds );
-            SampleNumberDisplay *snd;
-            while ( (snd = it2.current()) != 0 ) {
-                ++it2;
-                files.append(""+snd->getAssignedFile());
-            }
-        }
-    }
-    if(files.count()>0){
-        copyFilesToDir(files,dir);
-    }
-}
-
-
-/*!
-    \fn ProjectManager::copyFilesToDir(QStringList files, QString dir)
- */
-int ProjectManager::copyFilesToDir(QStringList files, QString dir)
-{
-    for ( QStringList::Iterator it = files.begin(); it != files.end(); ++it ) {
-        copyFileToDir(*it,dir);
-    }
-}
-
-
-/*!
-    \fn ProjectManager::copyFileToDir(QString file, QString dir)
- */
-int ProjectManager::copyFileToDir(QString inputfile, QString dir)
-{
-    
-     QFile input(inputfile);
-     if(!input.open(IO_ReadOnly)){
-         cout<<"cannot read "<<inputfile<<"\n";
-         return 1;
-     }
-     QFile output(dir+"/"+QFileInfo(inputfile).fileName());
-     if(!output.open(IO_WriteOnly)){
-         cout<<"cannot write "<<output.name()<<"\n";
-         return 1;
-     }
-     output.writeBlock(input.readAll());
-     output.close();
-     input.close();
-     return 0;
-}
-
-
-/*!
-    \fn ProjectManager::xmlToStacks(QDomNode xml)
- */
-void ProjectManager::xmlToStacks(QDomNode xml)
-{
-    if(!xml.isNull()){
-        QDomNodeList stacks=xml.childNodes();
-        for (int i=0;i<stacks.count();i++){
-            QDomNode stack=stacks.item(i);
-            xmlToStack(stack);
-        }
-    }
-}
-
-/*!
-    \fn ProjectManager::xmlToStack(QDomNode xml)
- */
-void ProjectManager::xmlToStack(QDomNode xml)
-{
-   if(!xml.isNull()){
-        long left_pos=xml.attributes().namedItem("left").toAttr().value().toLong();
-        long right_pos=xml.attributes().namedItem("right").toAttr().value().toLong();
-        QDomNodeList stackElements=xml.childNodes();
-        for (int i=0;i<stackElements.count();i++){
-            QDomNode stackElement=stackElements.item(i);
-            xmlToStackElement(stackElement,left_pos,right_pos);
-        }
-    }
-}
-
-
-
-
-
-/*!
-    \fn ProjectManager::xmlToStackElement(QDomNode xml, long left, long right)
- */
-void ProjectManager::xmlToStackElement(QDomNode xml, long left, long right)
-{
-    QFileInfo finfo(filename);
-    QString uncompressedDir=soundManager->getTempDir()+"/"+finfo.baseName();
-    
-    int index=xml.attributes().namedItem("index").toAttr().value().toInt();
-    int scene=xml.attributes().namedItem("scene").toAttr().value().toInt();
-    QString stackElemFilename=xml.attributes().namedItem("filename").toAttr().value();
-    bool current=xml.attributes().namedItem("current").isNull()?FALSE:
-                    xml.attributes().namedItem("current").toAttr().value().toInt();
-    
-    copyFileToDir(uncompressedDir+"/"+stackElemFilename,soundManager->getTempDir());
-    cout<<"copying "<<uncompressedDir+"/"+stackElemFilename<<" to "<<soundManager->getTempDir()<<endl;
-    emit(addStackElementS(left,right,
-            soundManager->getTempDir()+"/"+stackElemFilename,index,scene,current));
-}
-
-
-void ProjectManager::setBpmModifier(const QString& theValue) {
-    bpmModifier = theValue;
-}
