@@ -80,7 +80,8 @@ protected:
     bool hasLADSPA;
     bool hasEnvelope;
 
-    
+    float* exportMultiplexedBuffer(long,long,bufferType type=FOR_OUTPUT);
+    void exportMultiplexedBuffer(float*,long,long,bufferType type=FOR_OUTPUT);
 
     float* exportDerivatedLeftBuffer(long,long,bufferType type=FOR_OUTPUT);
     float* exportDerivatedRightBuffer(long,long,bufferType type=FOR_OUTPUT);
@@ -107,8 +108,6 @@ public:
     float* getLeftChannel(bufferType type=FOR_OUTPUT);
     float* getRightChannel(bufferType type=FOR_OUTPUT);
     void exportMultiplexedShortBuffer(short* data, long,long,bufferType type=FOR_OUTPUT);
-    float* exportMultiplexedBuffer(long,long,bufferType type=FOR_OUTPUT);
-    void exportMultiplexedBuffer(float*,long,long,bufferType type=FOR_OUTPUT);
 
     void setNbFrames(long);
     int getBps();
@@ -124,8 +123,7 @@ public:
     void setHasEnvelope(bool tf);
     QByteArray getChunkAsAudioFile(long start, long end, bufferType type=FOR_OUTPUT);
     bool getHasLADSPA();
-    virtual long insertFileAt(QString filename,long start_sample);
-    virtual void replaceFileAt(QString filename,long start_sample,long end_sample);
+    void insertFileAt(QString filename,long start_sample);
     void enlargeBuffersAt(long start_sample,long nb_frames);
     bool getHasEnvelope();
 
