@@ -71,10 +71,9 @@ QMemArray<long> SoundManager::analyse(const double treshold,
     #ifdef HAS_AUBIO
         else if(analysisMethod==COMPLEX_DOMAIN || analysisMethod==HFC
                             || analysisMethod==PHASE_DIFF || analysisMethod==COMPLEX_DOMAIN)
-        return analyse_aubio_onsets(treshold,window,start_sample,end_sample);
-        //else
-        //    return error;
+        return analyse_aubio_onsets(treshold,window,start_sample,end_sample);        
     #endif // HAS_AUBIO
+    //else return error;
 }
 
 QMemArray<long> SoundManager::analyse_freq_domain(const double treshold,
@@ -672,6 +671,7 @@ void SoundManager::resample(list<long>sortedPos,double new_to_oldBPM_ratio)
 #endif;
         QProgressDialog progress("Time stretching/expanding...","Abort",getFrames(),NULL,"progress",TRUE);
         progress.setMinimumDuration(2000);
+        progress.setProgress(0);
         SoundTouch* st=new SoundTouch();
 	st->setSampleRate(getRate());
 	st->setChannels(getChannels());
@@ -697,6 +697,7 @@ void SoundManager::resample(list<long>sortedPos,double new_to_oldBPM_ratio)
 	for (it=sortedPos.begin();it!=sortedPos.end();++it){
 		startpos=endpos;
 		endpos=(int)*it;
+                cout<<"resampling from: "<<startpos<<" to: "<<endpos<<endl;
 		input_buffer_size=endpos-startpos;
 		output_buffer_size=(int)ceil((endpos-startpos)*(1/new_to_oldBPM_ratio));
 
@@ -724,10 +725,9 @@ void SoundManager::resample(list<long>sortedPos,double new_to_oldBPM_ratio)
                                                                     tmp_wave2,currentPos,returned);
 #endif
                        currentPos+=returned;
-                       if(true/*i%1000==0*/){
+                       if(true){
                             progress.setProgress(currentPos);
-                            progress.setLabelText("Analyzing input signal...(frame: "+QString::number(currentPos)+")");
-                            QApplication::flushX();
+                            progress.setLabelText("Time stretching/expanding...(frame: "+QString::number(currentPos)+")");
                         }
 		}while(returned!=0);
                 zaparr(tmp_wave);
@@ -760,9 +760,17 @@ void SoundManager::resample(list<long>sortedPos,double new_to_oldBPM_ratio)
 
         zaparr(tmp_wave2);
         zaparr(outputWave);
-
+        if(getHasLADSPA()) initBuffer(AFTER_LADSPA,getFrames());
+        if(getHasEnvelope()) initBuffer(AFTER_ENVELOPE,getFrames());
+        getEffects()->setNbFrames(getFrames());
+        cout<<"timestretch end\n";
+        emit(reinitLADSPAValues());
         zapInstantEBuffer();
-        emit(waveChanged());
+        if(getEffects()->getCurrent()) applyPlugin(getEffects()->getCurrent()); //reapply current plugin
+        else if(getHasEnvelope()) applyEnvelope();
+        else emit(waveChanged());
+
+
 }
 
 
@@ -949,6 +957,7 @@ void SoundManager::applyPlugin(LADSPAEffect* effect,long start_sample, long end_
 
     QProgressDialog progress("Applying pugin...","Abort",getFrames(),NULL,"progress",TRUE);
     progress.setMinimumDuration(1000);
+    progress.setProgress(0);
 
     //audio ports
 
@@ -961,7 +970,6 @@ void SoundManager::applyPlugin(LADSPAEffect* effect,long start_sample, long end_
     //end audio ports
 
     effect->init(getRate(),inputBufferLeft,inputBufferRight,outputBufferLeft,outputBufferRight);
-    //effect->startControlPortValues(start_sample);
     effect->startPortValues(start_sample);
     cout<<"applying plugin from sample: "<<start_sample<<" to sample:"<<end_sample<<"\n";
     long processedSamples=0;
@@ -976,7 +984,7 @@ void SoundManager::applyPlugin(LADSPAEffect* effect,long start_sample, long end_
                 processedSamples+=lastChunk;
                 effect->advancePortValues(lastChunk);
             }
-            if((i/1024)%100==0){
+            if(i%(102400)==0){
                 progress.setProgress(i);
                 progress.setLabelText("Applying pugin...(frame: "+QString::number(i)+")");
             }
@@ -985,11 +993,13 @@ void SoundManager::applyPlugin(LADSPAEffect* effect,long start_sample, long end_
             }
             assert(processedSamples<=getFrames());
     }
+    progress.close();
     if(hasEnvelope){
         applyEnvelope();
     }else{
-        this->zapInstantEBuffer();
-        //emit(waveChanged(start_sample,end_sample));  //should be..
+        //force spectrogram repaint
+        if(hiresfreq_subband_energies) zaparr(hiresfreq_subband_energies);
+        //this->zapInstantEBuffer();
         emit(waveChanged()); //is ..
     }
 }
@@ -997,8 +1007,6 @@ void SoundManager::applyPlugin(LADSPAEffect* effect,long start_sample, long end_
 
 void SoundManager::applyPlugin(LADSPAEffect* effect){
     applyPlugin(effect,0,getFrames());
-    this->zapInstantEBuffer();
-    emit(waveChanged());
 }
 
 
@@ -1024,7 +1032,7 @@ LADSPAEffects* SoundManager::getEffects()
  */
 void SoundManager::zapInstantEBuffer()
 {
-    cout<<"Zapping buffers\n";
+    cout<<"Zapping Instant Energy buffers\n";
     if(instant_buffer) zaparr(instant_buffer);
     if(hirestemp_subband_energies) zaparr(hirestemp_subband_energies);
     if(hiresfreq_subband_energies) zaparr(hiresfreq_subband_energies);
@@ -1045,9 +1053,11 @@ float** SoundManager::compute_subband_energies(int subband_number,
                                                                                                     bufferType type)
 {
 
+    cout<<"Computing fft\n";
     assert(start_sample>=0 && end_sample<=getFrames());
     QProgressDialog progress("Computing FFT...","Abort",end_sample-start_sample,NULL,"progress",TRUE);
     progress.setMinimumDuration(2000);
+    progress.setProgress(0);
 
     //convert start/end frequency to fft index
     float start_index=(startfreq*frames)/getRate();
@@ -1144,11 +1154,9 @@ float** SoundManager::compute_subband_energies(int subband_number,
                 //end update minimas and maximas
             }
             //end compute the energy of n subbands
-            if(i%5000==0){
-                progress.setProgress(i);
+            if((i-start_sample)%(advance_frames*100)==0){
+                progress.setProgress(i-start_sample);
                 progress.setLabelText("Computing FFT...(frame: "+QString::number(i)+")");
-                QApplication::eventLoop()->processEvents(QEventLoop::AllEvents);
-                QApplication::flushX();
             }
     }
     if(gaussian) zaparr(gaussian);
@@ -1302,9 +1310,9 @@ void SoundManager::recompute_subband_energies(){
 /*!
     \fn SoundManager::setFFTParams(int,int,int,int,int,in,int,int,bool)
  */
-                void SoundManager::setFFTParams(int hf_w,int hf_a,int hf_nb,int hf_p,int hf_sf,int hf_ef,
-                int ht_w,int ht_a,int ht_nb, int ht_p,int ht_sf,int ht_ef,
-                int w, bool ssm)
+void SoundManager::setFFTParams(int hf_w,int hf_a,int hf_nb,int hf_p,int hf_sf,int hf_ef,
+int ht_w,int ht_a,int ht_nb, int ht_p,int ht_sf,int ht_ef,
+int w, bool ssm)
 {
 
 
@@ -1326,7 +1334,9 @@ void SoundManager::recompute_subband_energies(){
 
         substractSpectralMean=ssm;
 
-        recompute_subband_energies();
+        //recompute_subband_energies();
+        //this->zapInstantEBuffer();
+        if(!getHasEnvelope() && !getHasLADSPA()) this->zapInstantEBuffer();
         emit(fftParamsChanged());
         emit(analysisParamsChanged());
 }
@@ -1738,7 +1748,9 @@ void SoundManager::applyEnvelope()
         }
     }
     cout<<"Envelope applied\n";
-    this->zapInstantEBuffer();
+    //force spectrogram repaint
+    if(hiresfreq_subband_energies) zaparr(hiresfreq_subband_energies);
+    //this->zapInstantEBuffer();
     //emit(waveChanged(start_sample,end_sample));  //should be..
     emit(waveChanged()); //is ..
 }
@@ -1799,3 +1811,35 @@ bool SoundManager::getHasEnvelope()
 {
     return hasEnvelope;
 }
+
+
+/*!
+    \fn SoundManager::getFileExtension()
+ */
+QString  SoundManager::getFileExtension()
+{
+    return fileManager->getFilenameExtension();
+}
+
+
+/*!
+    \fn SoundManager::getTempDir()
+ */
+QString SoundManager::getTempDir()
+{
+    return fileManager->getTempDir();
+}
+
+
+/*!
+    \fn SoundManager::canOpen(QString file)
+ */
+bool SoundManager::canOpen(QString file)
+{
+    bool openable=FALSE;
+    SF_INFO tempsfinfo;
+    SNDFILE* tmp_sndfile= sf_open(file, SFM_READ, &tempsfinfo);
+    if(tmp_sndfile==0) openable=FALSE; else openable=TRUE;
+    sf_close(tmp_sndfile);
+    return openable;
+}
