@@ -89,12 +89,18 @@ void UeberStyle::drawControl( ControlElement element,
     switch (element) {
         case CE_PushButton:{
             QPushButton* pushbutton=(QPushButton*)widget;
-            p->fillRect(r,QBrush(cg.background()));
-            p->drawImage(0,0,
-                         getButtonImage(start_image,r,
-                                        flags & (Style_Sunken | Style_Down| Style_On),
-                                        pushbutton->isToggleButton(),cg));
-            break;
+            if(pushbutton->width()<button_embed_image_vec[0].width ||
+               pushbutton->height()<button_embed_image_vec[0].height){
+                QMotifStyle::drawControl(element,p,widget,r,cg,flags,opt);
+                break;
+            }else{
+                p->fillRect(r,QBrush(cg.background()));
+                p->drawImage(0,0,
+                            getButtonImage(start_image,r,
+                                            flags & (Style_Sunken | Style_Down| Style_On),
+                                            pushbutton->isToggleButton(),cg));
+                break;
+            }
         }
         case CE_PushButtonLabel:{
             QMotifStyle::drawControl(element,p,widget,r,cg,flags,opt);
@@ -356,13 +362,18 @@ QRect UeberStyle::subRect(SubRect r, const QWidget *widget) const
             return QRect();
         }
         case SR_PushButtonContents:{
-            QRect rect=widget->rect();
-            QRect newrect=rect;
-            newrect.setBottom(rect.y()+rect.height()-16);
-            newrect.setTop(rect.y()+6);
-            newrect.setLeft(rect.x()+10);
-            newrect.setRight(rect.x()+rect.width()-12);
-            return newrect;
+            if(widget->width()<button_embed_image_vec[0].width ||
+               widget->height()<button_embed_image_vec[0].height){
+                    return QMotifStyle::subRect(r,widget);
+               }else{
+                    QRect rect=widget->rect();
+                    QRect newrect=rect;
+                    newrect.setBottom(rect.y()+rect.height()-16);
+                    newrect.setTop(rect.y()+6);
+                    newrect.setLeft(rect.x()+10);
+                    newrect.setRight(rect.x()+rect.width()-12);
+                    return newrect;
+               }
         }
         default: return QMotifStyle::subRect(r,widget);
     }
@@ -376,6 +387,7 @@ QSize UeberStyle::sizeFromContents( ContentsType contents,
     QSize sz(contentsSize);
     switch(contents){
         case CT_PushButton:{
+
             QRect rect=subRect(SR_PushButtonContents,widget);
             sz = QCommonStyle::sizeFromContents(contents, widget, contentsSize, opt);
             //cout<<"[1]name: "<<widget->name()<<" width: "<<sz.width()<<" height: "<<sz.height()<<endl;
