@@ -41,6 +41,7 @@ WaveCanvas::WaveCanvas(QWidget* parent)
     rightMaximaBuffer=0;
     spectrogramMaxBuffer=0;
     spectrogramMaxBufferNbValues=0;
+    maxBufferNbValues=0;
     visibleWidth=0;
 }
 
@@ -60,8 +61,12 @@ WaveCanvas::~WaveCanvas()
         \sa drawBackground()
 */
 void WaveCanvas::drawBackgroundImage(long start_sample, long end_sample){
+    QMutex mutex;
+    mutex.lock();
+    //cout<<"in wavecanvas (parent ["<<parent()->parent()->name()<<"]) drawBackgroundImage()\n";
     if(viewMode==SPECTRUM_VIEWMODE) drawSpectrum(start_sample,end_sample);
     else drawWave(start_sample,end_sample);
+    mutex.unlock();
 }
 
 /**
@@ -302,6 +307,7 @@ void WaveCanvas::drawWave(long start_sample,long end_sample)
                     leftMaximaBuffer[i].hasValue=0;
                     rightMaximaBuffer[i].hasValue=0;
                 }
+                maxBufferNbValues=(int)ceil(soundManager->getFrames()/jump);
             }
             for (int i=start_sample;i<=end_sample-jump;i=i+jump){
                     float maxL=0;
@@ -365,6 +371,7 @@ void WaveCanvas::drawWave(long start_sample,long end_sample)
  */
 void WaveCanvas::drawSpectrum(long start_sample,long end_sample)
 {
+
     std::cout<<"start drawing spectrum\n";
     QColor color(0,255,0);
     int nbbands=soundManager->getHiresFreqNbBands();
@@ -376,10 +383,11 @@ void WaveCanvas::drawSpectrum(long start_sample,long end_sample)
     float spectralMeanOverFrames=(maximaLog-minimaLog)/2;
     int fftAdvance=soundManager->getHiresFreqFFTAdvance();
 
-    /*
-    QProgressDialog progress("Drawing specturm...",NULL,end_sample-start_sample,NULL,"progress",TRUE);
+
+    QProgressDialog progress("Drawing spectrum...",NULL,end_sample-start_sample,NULL,"progress",TRUE);
      progress.setMinimumDuration(2000);
-    */
+     progress.setProgress(0);
+
      if(soundManager!=0 && soundManager->hasSound()&& zoomRatio>=1){
             long jump=zoomRatio;
             if(jump<1) jump=1;
@@ -440,11 +448,10 @@ void WaveCanvas::drawSpectrum(long start_sample,long end_sample)
             int x=c_x;
             float bandHeightFactor=float(v_height)/float(nbbands);
             float bandWidthFactor=float(fftAdvance)/float(zoomRatio);
-            MyMath::smartRound bwFactorRound;
-            bwFactorRound.init(bandWidthFactor,v_width);
-            MyMath::smartRound bhFactorRound;
-            bhFactorRound.init(bandHeightFactor,
-                               round(v_height/bandHeightFactor));
+            MyMath::smartRoundSum bwFactorRound;
+            bwFactorRound.init(bandWidthFactor);
+            MyMath::smartRoundSum bhFactorRound;
+            bhFactorRound.init(bandHeightFactor);
             std::cout<<"band height factor: "<<bandHeightFactor<<" band width factor:"<<bandWidthFactor<<"\n";
             std::cout<<"jump: "<<jump<<"\n";
             float max=FLT_MIN;
@@ -465,12 +472,16 @@ void WaveCanvas::drawSpectrum(long start_sample,long end_sample)
                 }
             }
             int roundoff=0;
+            float test_roundoff=0;
             int lastchunk=end_sample+jump>soundManager->getFrames()?
                                         soundManager->getFrames()%jump:0;
+            cout<<"Last chunk: "<<lastchunk<<endl;
             for (int i=start_sample;i<end_sample-lastchunk;i=i+jump){
-                    bwFactorRound.round();
+                    bwFactorRound.myround();
+                    int y=0;
+                    bhFactorRound.init(bandHeightFactor);
                     for(int band=0;band<nbbands;band++){
-                        bhFactorRound.round();
+                        bhFactorRound.myround();
                         max=FLT_MIN;
                         if(!spectrogramMaxBuffer[i/jump].hasValue){
                             for (int j=i;j<=i+jump;j=j+fftAdvance){
@@ -492,43 +503,49 @@ void WaveCanvas::drawSpectrum(long start_sample,long end_sample)
                         colorValue=colorValue>255?255:colorValue<0?0:colorValue;
                         //color.setRgb(colorValue,colorValue,colorValue);
                         color.setHsv(colorValue,255,255);
-                        //if(hasPixmap) return; //avoid cascading redraws
                         if(colorValue!=0){
                             localpainter.setPen(color);
                             if(bandHeightFactor<=1.0 && bandWidthFactor<=1.0){
                                 localpainter.drawPoint(x,band*bandHeightFactor);
                             }else if (bandHeightFactor>1.0 && bandWidthFactor<=1.0){
-                                localpainter.drawLine(x,band*bandHeightFactor,
-                                                                        x,band*bandHeightFactor+bandHeightFactor);
+                                localpainter.drawLine(x,y,x,bhFactorRound.rounded());
                             }else if(bandWidthFactor>1.0 && bandHeightFactor<=1.0){
-                                if(x!=x+bwFactorRound.rounded()){
+                                if(x!=c_x+bwFactorRound.rounded()){
                                     localpainter.drawLine(x,band*bandHeightFactor,
-                                            x+bwFactorRound.rounded(),band*bandHeightFactor);
+                                            c_x+bwFactorRound.rounded(),band*bandHeightFactor);
                                 }
                             }else{
-                                localpainter.fillRect(x,band*bandHeightFactor,
-                                        bwFactorRound.rounded(),ceil(bandHeightFactor),
-                                        QBrush(color));
+                                localpainter.fillRect(x,y,
+                                        c_x+bwFactorRound.rounded(),bhFactorRound.rounded(),QBrush(color));
 			    }
                          }
+                         if(bandHeightFactor<=1){
+                             y++;
+                         }else{
+                             y=bhFactorRound.rounded();
+                         }
                     }
                     if(bandWidthFactor<=1){
                         x++;
                         roundoff++;
                     }else{
-                        x+=bwFactorRound.rounded();//ceil(bandWidthFactor);
-                        roundoff+=bwFactorRound.rounded();
+                        test_roundoff+=bandWidthFactor;
+                        roundoff=bwFactorRound.rounded();
+                        x=c_x+bwFactorRound.rounded();//ceil(bandWidthFactor);
+                        /*
+                        cout<<"value: "<<bandWidthFactor<<" rounded to: "<<bwFactorRound.rounded()<<" total: "<<roundoff<<" should be: "<<test_roundoff<<endl;
+                        */
+
                     }
-                    //cout<<"rounded to: "<<bwFactorRound.rounded()<<endl;
-                    /*
-                    if(i%(jump*100)==0){
-                        progress.setProgress(i);
+
+                    if((i-start_sample)%(jump*100)==0){
+                        progress.setProgress(i-start_sample);
                         progress.setLabelText("Drawing spectrum...(frame: "+QString::number(i)+")");
                     }
-                    */
+
             }
             if(lastchunk>0){
-                localpainter.fillRect(x,0,x+lastchunk/zoomRatio,v_height,QBrush(blue));
+                localpainter.fillRect(x,0,v_width-c_x-x,v_height,QBrush(blue));
             }
             font.setPixelSize(12);
             font.setWeight(QFont::Bold);
@@ -560,8 +577,7 @@ void WaveCanvas::drawSpectrum(long start_sample,long end_sample)
             localpainter.drawText(c_x+v_width-font_metrics.width(lowFreqText),
                                   v_height-font_metrics.height(),lowFreqText);
             hasPixmapV=TRUE;
-            cout<<"real width: "<<v_width;
-            cout<<" rounded width: "<<roundoff<<endl;
+            cout<<"real width: "<<v_width<<" rounded width: "<<roundoff<<endl;
     }
     std::cout<<"end drawing spectrum\n";
 }
@@ -600,6 +616,7 @@ void WaveCanvas::zapBuffers()
     //cout<<"in wavecanvas (parent ["<<parent()->parent()->name()<<"]) started zapping wave canvas buffers\n";
     if (leftMaximaBuffer) zaparr(leftMaximaBuffer);
     if (rightMaximaBuffer) zaparr(rightMaximaBuffer);
+
     if (spectrogramMaxBuffer){
         for (int i=0;i<spectrogramMaxBufferNbValues;i++){
             if (spectrogramMaxBuffer[i].max){
@@ -624,6 +641,7 @@ void WaveCanvas::zapBuffers(long start, long end)
         if (rightMaximaBuffer && &rightMaximaBuffer[i]) rightMaximaBuffer[i].hasValue=0;
         if (spectrogramMaxBuffer && &spectrogramMaxBuffer[i]) spectrogramMaxBuffer[i].hasValue=0;
     }
+    cout<<"in wavecanvas (parent ["<<parent()->parent()->name()<<"]) Buffers cleaned\n";
 }
 
 
@@ -635,3 +653,19 @@ void WaveCanvas::setVisibleWidth(int w)
 {
     visibleWidth=w;
 }
+
+
+/*!
+    \fn WaveCanvas::emptyBuffers()
+ */
+void WaveCanvas::emptyBuffers()
+{
+
+    for (int i=0;i<maxBufferNbValues;i++){
+        leftMaximaBuffer[i].hasValue=0;
+        rightMaximaBuffer[i].hasValue=0;
+    }
+    for (int i=0;i<spectrogramMaxBufferNbValues;i++){
+            spectrogramMaxBuffer[i].hasValue=FALSE;
+    }
+}
