@@ -32,7 +32,6 @@
 #include "soundmanager.h"
 #include "defs.h"
 #include "mymath.h"
-#include "rms.h"
 /**
 @author Predrag Viceic
 \class WaveCanvas
@@ -67,7 +66,6 @@ public:
     struct maxAndMin{
         float max;
         float min;
-        float rms;
         int hasValue;
     };
 
@@ -92,8 +90,6 @@ protected:
     bool drawing;
     int pixmapXOrigin; /**< holds the first visible pixel x coord*/
     int visibleWidth;
-    rms_env* rmsL;
-    rms_env* rmsR;
 private:
     long maxZoomRatio; /**< used for ruler coord system*/
     QImage* background;
@@ -101,8 +97,6 @@ private:
     bool hasPixmapV;
     maxAndMin* leftMaximaBuffer;
     maxAndMin* rightMaximaBuffer;
-    maxAndMin* leftRMSBuffer;
-    maxAndMin* rightRMSBuffer;
     long maxBufferNbValues;
     spectrogramMax* spectrogramMaxBuffer;
     long spectrogramMaxBufferNbValues;
